@@ -50,7 +50,7 @@ class StrategyResolver(IResolver):
             if 'timeframe' not in config:
                 logger.warning(
                     "DEPRECATED: Please migrate to using 'timeframe' instead of 'ticker_interval'."
-                    )
+                )
                 strategy.timeframe = strategy.ticker_interval
 
         if strategy._ft_params_from_file:
@@ -119,7 +119,7 @@ class StrategyResolver(IResolver):
         - default (if not None)
         """
         if (attribute in config
-                and not isinstance(getattr(type(strategy), 'my_property', None), property)):
+                and not isinstance(getattr(type(strategy), attribute, None), property)):
             # Ensure Properties are not overwritten
             setattr(strategy, attribute, config[attribute])
             logger.info("Override strategy '%s' with value in config file: %s.",
